<?php
namespace App\Contracts\Payment;

use App\Models\Order;

interface PaymentGatewayServiceContract
{

    /**
     * specifies which order this payment gateway instance is meant for. 
     */
    public function receivePaymentFor(Order $order);

    /**
     * Since every payment gateway has their unique requirements for initiating payment, this method
     * is mainly for preparing all the data necessary to successfully initiate a payment on any given
     * payment gateway regardless of their requirements. 
     */
    public function getDataForPaymentInitialization();



    /**
     * this is the method that serves as the entry point for any pgs to process a payment.
     * this method takes no argument and usually invokes the initiatePayment() of any pgs
     */
    public function acceptPayment();

    /**
     * this is used to initiate a payment from any given payment gateway 
     * Using their respective API requirements
     * It usually returns a generated payment link that's used to initialize a payment process
     * It's result updates a order status to 'initiated'
     */
    public function initiatePayment();


    /**
     * This verifies any transaction from any given payment gateway and it's result is used to update 
     * a p status to either 'successful' or 'failed'
     * @param string $reference refers to the paymentReference (of the transaction) you want to verify
     */
    public static function verifyPayment(string $reference);

}