<?php

namespace App\Http\Controllers;

use App\Models\BillingData;
use Illuminate\Http\Request;

class BillingDataController extends Controller
{
    public function store($safeData)
    {
        $created = auth()->user()->billingData()->create($safeData);

        $created ? flash('billing info updated') : flash('operation failed');

        return back();
    }

    public function storeOrUpdate(Request $request)
    {
        $safeData = $request->validate($this->getValidationRules());

        $userHasBillingData = auth()->user()->billingData?->id;

        return $userHasBillingData ? $this->update($safeData) : $this->store($safeData);
    }

    public function update($safeData)
    {
        $updated = auth()->user()->billingData()->update($safeData);

        $updated ? flash('billing info updated') : flash('operation failed');

        return back();
    }

    public function getValidationRules()
    {
        return [
            'first_name' => 'required',
            'last_name' => 'required',
            'company' => 'nullable',
            'address_line1' => 'required',
            'address_line2' => 'nullable',
            'city' => 'required',
            'state' => 'required',
            'zip' => 'nullable',
            'phone' => 'nullable',
        ];
    }
}
