<?php

namespace App\Http\Controllers;

use App\Models\Product;
use Illuminate\Http\Request;
// use Gloudemans\Shoppingcart\Cart;
use Illuminate\Session\SessionManager;
use Illuminate\Contracts\Events\Dispatcher;
use Gloudemans\Shoppingcart\Facades\Cart;

class CartController extends Controller
{
    /**
     * blackbox
     * move product from wishlist to cart
     * @param Product $product
     * 
     * @return [type]
     */
    public function moveToCart(Product $product)
    {
        // verify that item doesn't exist in cart
        $foundCollection = Cart::search(function ($cartItem, $rowId) use ($product) {
            return (int) $cartItem->id === (int) $product->id;
        });
        if (!blank($foundCollection->first()))
            flash()->position('bottom-right')->addInfo('item already exists in cart');
        else {
            Cart::add($product); //step1: add to cart
            $this->removeFromWishlist($product); // step2: remove from wishlist
            flash()->position('bottom-right')->addSuccess('item moved to cart');
        }
        return back();
    }


    public function updateCart(Request $request)
    {
        $size = $request->size;
        $productId = $request->product;
        // verify that item doesn't exist in cart
        $foundCollection = Cart::search(function ($cartItem, $rowId) use ($productId) {
            return (int) $cartItem->id === (int) $productId;
        });
        $foundItem = $foundCollection->first();

        if (!blank($foundItem))
            $rowId = $foundItem->rowId;
        else {
            Cart::add(Product::find($productId), 1);
            $foundCollection = Cart::search(function ($cartItem, $rowId) use ($productId) {
                return (int) $cartItem->id === (int) $productId;
            });
            $foundItem = $foundCollection->first();
            $rowId = $foundItem->rowId;
        }
        Cart::update($rowId, [
            'options' =>
                ['size' => $size]
        ]);
        return back();
    }



    /**
     * blackbox
     * move product from cart to wishlist
     * @param Product $product
     * 
     * @return [type]
     */
    public function moveToWishlist(Product $product)
    {
        // verify that item doesn't exist in wishlist
        $foundCollection = Cart::instance('wishlist')->search(function ($cartItem, $rowId) use ($product) {
            return (int) $cartItem->id === (int) $product->id;
        });
        if (!blank($foundCollection->first()))
            flash()->position('bottom-right')->addInfo('item already exists in wishlist');
        else {
            $this->removeFromCart($product);// Step 1: remove from cart
            Cart::instance('wishlist')->add($product);// Step2: add to wishlist
            flash()->position('bottom-right')->addSuccess('item moved to wishlist');
        }
        return back();
    }


    public function removeFromWishlist(Product $product)
    {
        // step2: remove from wishlist : To remove item from the wishlist, we need to first get the rowId
        $foundCollection = Cart::instance('wishlist')->search(function ($cartItem, $rowId) use ($product) {
            return (int) $cartItem->id === (int) $product->id;
        });
        Cart::remove($foundCollection?->first()?->rowId);
    }

    public function removeFromWishlistWithRedirect(Product $product)
    {
        // step2: remove from wishlist : To remove item from the wishlist, we need to first get the rowId
        $foundCollection = Cart::instance('wishlist')->search(function ($cartItem, $rowId) use ($product) {
            return (int) $cartItem->id === (int) $product->id;
        });
        if ($foundCollection?->first()?->rowId) {
            Cart::remove($foundCollection?->first()?->rowId);
            flash()->position('bottom-right')->addSuccess('item removed from wishlist');
        }

        return back();
    }

    public function removeFromCart($product)
    {
        // Step 1: remove from cart : To remove item from the cart, we need to first get the rowId
        $foundCollection = Cart::instance('default')->search(function ($cartItem, $rowId) use ($product) {
            return (int) $cartItem->id === (int) $product->id;
        });
        Cart::remove($foundCollection?->first()?->rowId);
    }


    public function removeFromCartWithRedirect(Request $request, Product $product)
    {
        $this->removeFromCart($product);
        flash()->position('bottom-right')->addSuccess('item removed from cart');
        return back();
    }

    public function addToCartWithRedirect(Request $request, Product $product)
    {
        Cart::add($product);
        flash()->position('bottom-right')->addSuccess('item added to cart');
        return back();
    }
}
