<?php

namespace App\Http\Controllers;

use App\Models\DeliveryInfo;
use App\Models\Order;
use Illuminate\Http\Request;
use App\Http\Requests\CheckoutRequest;

class CheckoutController extends Controller
{
    /**
     * Handle the incoming request.
     */
    public function __invoke(CheckoutRequest $request)
    {

        $pendingOrder = $this->handlePaymentPrerequisites($request);
        // dd($pendingOrder, session('delivery_info'));
        // step 3: initialize payment
        return (new PaymentController)->handlePayment($pendingOrder);

        // the job of this method is to receive the client (billing_data) and the order
        // and send it to the payment controller to handle the story

    }



    // helpers
    /**
     * handles the prerequisites for making a payment and returns a pending order
     * @param mixed $request
     * 
     * @return [type]
     */
    public function handlePaymentPrerequisites(Request $request): Order
    {
        // get client delivery info at checkout
        $clientInfo = $request->except('_token');
        $identifier = uniqid(authy()->id . '_'); // for this order
        $cartItemsInJson = json_encode(getCartContents());

        // step2a:create the initial setup data for the order
        $pendingOrder = authy()->orders()->create([
            'identifier' => $identifier,
            'pgs_id' => 0,//default
            'content' => $cartItemsInJson,
            'cart_item_ids' => implode(',', array_keys($this->getCartItemsWithKeys())),
            'items_count' => getCartContents()->count(),
            'total_amount' => getCart()->total(),
        ]);

        // dd($pendingOrder);

        // create new delivery info for the order and store in the session, if trx was successful then store to db
        session()->put('delivery_info', $request->except('_token'));

        return $pendingOrder;
    }

    /**
     * returns an array of cart items with their IDs as keys
     * @return array
     */
    public function getCartItemsWithKeys(): array
    {
        // for checking if an item has already been added to the cart
        foreach (getCartContents() as $cartItem) {
            $cartItemsIDs[$cartItem->id] = $cartItem;
        }

        return $cartItemsIDs ??= [];
    }




}
