<?php

namespace App\Http\Controllers;

use App\Models\Size;
use App\Models\Product;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Models\ProductCollection;
use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Storage;
use App\Http\Requests\StoreProductCollectionRequest;

class ProductCollectionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $allProductCollections = ProductCollection::all();
        return view('admin.product_collections.index', compact('allProductCollections'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.product_collections.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(StoreProductCollectionRequest $request)
    {
        $safeData = $this->handleProductCollectionImage($request);

        $newProductCollection = ProductCollection::create($safeData);

        return $this->providePositiveResponse($newProductCollection);
    }


    /**
     * display items in this collection
     * Display the specified resource.
     */
    public function show(ProductCollection $productCollection)
    {
        // $allCategories = ProductCollection::all();
        $allProducts = $productCollection->products;

        return view('website.product_collections.show', compact('allProducts', 'productCollection'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(ProductCollection $productCollection)
    {
        return view('admin.product_collections.edit', compact('productCollection'));

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(StoreProductCollectionRequest $request, ProductCollection $productCollection)
    {
        // dd($request->all());
        $safeData = $this->handleProductCollectionImage($request);
        $productCollection->update($safeData);
        return $this->providePositiveResponse($productCollection);

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(ProductCollection $productCollection)
    {
        //
    }


    public function search(Request $request)
    {
        // available url params are : searchfor,sort=['a-z', 'z-a', 'low-high', 'high-low', 'oldest', 'latest']
        $searchfor = $request->searchfor;
        $queryBuilder = Product::where('name', 'like', "%{$searchfor}%");
        $allProducts = match ($request->sort) {
            'a-z' => $queryBuilder->orderBy('name')->get(),
            'z-a' => $queryBuilder->orderByDesc('name')->get(),
            'lowest' => $queryBuilder->orderBy('price')->get(),
            'highest' => $queryBuilder->orderByDesc('price')->get(),
            'oldest' => $queryBuilder->orderBy('created_at')->get(),
            'latest' => $queryBuilder->orderByDesc('created_at')->get(),
            default => $queryBuilder->orderBy('name')->get(),
        };
        return view('website.products.search_results', compact('allProducts', 'searchfor'));
    }

    // helpers
    /**
     * returns safe data for storing in the db
     * @param mixed $request
     * 
     * @return array
     */
    public function handleProductCollectionImage(StoreProductCollectionRequest $request): array
    {
        if (
            $request->method() == 'PATCH'
            and $request->file('image')
            and in_array('image', $request->validated())
        ) {
            $productCollection = $request->productCollection;
            // delete old image from server
            $imgPathInStorage = str_replace('/storage', '', $productCollection->img_path);
            if (Storage::disk('public')->exists($imgPathInStorage))
                Storage::disk('public')->delete($imgPathInStorage);
        }

        $reqFile = $request->file('image');
        if (blank($reqFile))
            return $request->validated();

        $nowString = now()->toDateTimeLocalString();
        $filename = uniqid("{$nowString}_") . $reqFile->getClientOriginalName();
        $filePath = $reqFile->storePubliclyAs('public/product_collection_images', $filename);

        // save the file path that will be stored in db when the productCollection is created
        $filePathForDBStorage = str_replace('public', '/storage', $filePath); // format to store in db
        $request['img_path'] = $filePathForDBStorage;
        return ['img_path' => $request->img_path, ...$request->validated()];
    }

    private function providePositiveResponse(ProductCollection $product): RedirectResponse
    {
        if (request()->method() == 'PATCH') {
            $product ? flash('Product Collection updated') : flash()->addError('Oops! Try Again');
        } else
            $product ? flash('Product Collection created') : flash()->addError('Oops! Try Again');

        return back();
    }
}
