<?php

namespace App\Http\Controllers;

use Illuminate\View\View;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use App\Http\Requests\ProfileUpdateRequest;

class ProfileController extends Controller
{
    /**
     * Display the user's profile form.
     */
    public function edit(Request $request): View
    {
        return view('profile.edit', [
            'user' => $request->user(),
        ]);
    }

    /**
     * Update the user's profile information.
     */
    public function update(ProfileUpdateRequest $request): RedirectResponse
    {
        $request->user()->fill($request->validated());

        if ($request->user()->isDirty('email')) {
            $request->user()->email_verified_at = null;
        }

        $request->user()->save();

        flash('Profile updated 👍');

        return Redirect::route('profile.edit')
            ->with('status', 'profile-updated');
    }

    public function updateDp(Request $request)
    {
        // delete old ones if exists : OUT WITH THE OLD
        if (authy()->dp) {
            $oldFilePathInServerStorage = str_replace('/storage', '', authy()->dp);

            if (Storage::disk('public')->exists($oldFilePathInServerStorage))
                Storage::disk('public')->delete($oldFilePathInServerStorage);
        }

        // IN WITH THE NEW
        $request->validate(['dp' => 'required|image']);
        $newDp = $request->file('dp');
        $filename = auth()->id() . '_' . now() . $newDp->getClientOriginalName();
        $filePath = $newDp->storePubliclyAs('public/user_dps', $filename);

        $filePathForDBStorage = str_replace('public', '/storage', $filePath); // format to store in db
        $updated = authy()->update([
            'dp' => $filePathForDBStorage,
        ]);

        $updated ? flash('User display photo updated') : flash()->addError('Oops! Try Again');
        
        return back();
    }

    /**
     * Delete the user's account.
     */
    public function destroy(Request $request): RedirectResponse
    {
        $request->validateWithBag('userDeletion', [
            'password' => ['required', 'current_password'],
        ]);

        $user = $request->user();

        Auth::logout();

        $user->delete();

        $request->session()->invalidate();
        $request->session()->regenerateToken();

        return Redirect::to('/');
    }
}
