<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Models\PaymentAuthorizationInfo;
use App\PaymentGatewayServices\Paystack;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Order extends Model
{
    use HasFactory;

    protected $guarded = ['id'];

    // relationships

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }


    public function pgs(): BelongsTo
    {
        return $this->belongsTo(Pgs::class);
    }


    public function paymentInfo(): HasOne
    {
        return $this->hasOne(PaymentAuthorizationInfo::class);
    }

    public function deliveryInfo():HasOne
    {
        return $this->hasOne(DeliveryInfo::class);
    }

    // query scope

    /**
     * returns only successful queries
     * @param Builder $query
     * 
     * @return Builder
     */
    public function scopeSuccessful(Builder $query): Builder
    {
        return $query->where('status', 'success');
    }


    // helpers'

    /**
     * Returns the expected fees that I expect to be charged by any given pgs for this 
     * transaction
     * @return float
     */
    public function calculateMyFee(): float
    {
        $myExpectedFees = 0;
        $pgs_id = $this->pgs_id;
        $relatedPgs = Pgs::find($pgs_id);

        switch ($relatedPgs->name) {
            case 'paystack':
                $myExpectedFees = Paystack::getFeesForOrder($this);
                break;
            default:
                # code...
                break;
        }

        return $myExpectedFees;
    }


    public function getTotalAmountAsFloat(): float
    {
        return floatval(str_replace(',', '', $this->total_amount));
    }

    public function getTotalAmountAsInt(): float
    {
        return intval(str_replace([',', '.'], '', $this->total_amount));
    }
}
