<?php

namespace App\Models;
use App\Models\Size;
use App\Models\Picture;
use App\Models\Category;
use Illuminate\Support\Str;
use App\Observers\ProductObserver;
use Illuminate\Database\Eloquent\Model;
use App\Contracts\Gloudemans\BuyableTrait;
use Illuminate\Database\Eloquent\SoftDeletes;
use Gloudemans\Shoppingcart\Contracts\Buyable;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Attributes\ObservedBy;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

#[ObservedBy([ProductObserver::class])]
class Product extends Model implements Buyable
{
    // use SoftDeletes;

    use BuyableTrait;
    use HasFactory;

    protected $guarded = ['id'];


    // Relationships
    public function categories(): BelongsToMany
    {
        return $this->belongsToMany(ProductCollection::class, 'category_product');
    }

    public function sizes(): BelongsToMany
    {
        return $this->belongsToMany(Size::class)->withPivot('qty');

    }


    public function pictures(): HasMany
    {
        return $this->hasMany(Picture::class);
    }


    // helpers
    /**
     * returns a string containing all the names of the associated categories for this product
     * @return string
     */
    public function getCategories(): string|null
    {
        return
            (!blank($this->categories))
            ? (implode(', ', $this->categories->pluck('name')->toArray()))
            : null;
    }

    public function presentSizes()
    {
        $arrayOfSizes = $this->sizes()->pluck('name')->toArray();
        return $stringOfSizes = implode(' ', $arrayOfSizes);

    }

    public function getBrand()
    {
        return $this->brand ?? 'Create2Fit';
    }

    public function getStockQtyForSize(Size|string $size): int
    {
        if (!$size instanceof Size || is_string($size) || is_int($size))
            $size = Size::find($size);

        return $this->sizes->contains($size->id) ?
            $this->sizes()->where('size_id', $size->id)->first()->pivot?->qty : 0;
    }

    public function updateSlug()
    {
        $this->update(['slug' => Str::slug($this->name)]);
    }

    // ===================
    // relationships

    public function getMainPicture()
    {
        return $this->pictures()->defaultPicture()->first();
    }


    public function setMainPicture(string $path)
    {
        return $this->getMainPicture()->update([
            'path' => $path
        ]);
    }


}
