<?php
namespace App\Traits\Controllers;

use App\Models\Size;
use App\Models\Product;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Route;
use App\Http\Requests\StoreProductRequest;

trait ProductControllerHelpers
{

    /**
     * @param mixed $validated refers to validated data
     * @param mixed $newProduct refers to newProduct
     * 
     * @return [type]
     */
    public function handleAllSizes($validated, $product)
    {
        $selectedSizeIDs = Size::pluck('id');
        $product->sizes()->sync($selectedSizeIDs);

        foreach ($selectedSizeIDs as $sizeId)
            $product->sizes()->updateExistingPivot($sizeId, [
                'qty' => $validated["size_" . Size::find($sizeId)->name . "_qty"],
            ]);
    }


    /**
     * @param mixed $validated refers to validated data
     * @param mixed $product refers to newProduct
     * 
     * @return [type]
     */
    public function handleSelectedSizes($validated, Product $product)
    {
        $specificSizesAvailable = array_filter($validated, fn($elem, $key) => strstr($key, 'sizes'), ARRAY_FILTER_USE_BOTH);
        // remove a layer on the array
        $specificSizesAvailable = $specificSizesAvailable['sizes'];
        foreach ($specificSizesAvailable as $sizeAvailable)
            $arrayofSizeObjects[] = Size::where('name', $sizeAvailable)->first();
        $selectedSizeIDs = collect($arrayofSizeObjects)->pluck('id');

        // dd('here'); for both create and update
        $product->sizes()->sync($selectedSizeIDs);
        foreach ($selectedSizeIDs as $sizeId) {
            $product->sizes()->updateExistingPivot($sizeId, [
                'qty' => $validated["size_" . Size::find($sizeId)->name . "_qty"],
            ]);
        }
    }


    /**
     * Store a newly created resource in storage.
     */
    public function storeNewProduct(StoreProductRequest $request)
    {
        $newProduct = Product::create($request->validated());
        // handle product categories, after product creation, you then assign them to categories
        $newProduct->categories()->attach($request->validated()['categories']);

        return $newProduct;
    }

    private function handleProductSizes($request, $newProduct): void
    {
        $allSizesAreAvailable = in_array('all_sizes', $request->sizes);
        if ($allSizesAreAvailable)
            $this->handleAllSizes($request->validated(), $newProduct); // handle all sizes
        else
            $this->handleSelectedSizes($request->validated(), $newProduct); // handleSelectedSizes
    }

    private function handleProductImages(StoreProductRequest $request, Product $newProduct): void
    {
        $filteredFiles = array_filter($request->validated(), fn($key) => strstr($key, 'photo_'), ARRAY_FILTER_USE_KEY);
        
        foreach ($filteredFiles as $reqFile) {
            // store the file on server
            $nowString = now()->toDateTimeLocalString();
            $filename = uniqid("{$nowString}_") . $reqFile->getClientOriginalName();
            $filePath = $reqFile->storePubliclyAs('public/product_images', $filename);

            // store the file path in db
            $filePathForDBStorage = str_replace('public', '/storage', $filePath); // format to store in db
            $updated = $newProduct->pictures()->create([
                'path' => $filePathForDBStorage,
            ]);
        }
    }

    private function providePositiveResponse($newProduct): RedirectResponse
    {

        $newProduct ? flash('Product created') : flash()->addError('Product could not be created');

        return back();
    }

    /**
     * Store a newly created resource in storage.
     */
    public function updateExistingProductRelatedData(StoreProductRequest $request, Product $product)
    {
        // handle product categories
        $product->categories()->sync($request->validated()['categories']);

        // handle product sizes
        $allSizesAreAvailable = in_array('all_sizes', $request->sizes);
        if ($allSizesAreAvailable)
            $this->handleAllSizes($request->validated(), $product); // handle all sizes
        else
            $this->handleSelectedSizes($request->validated(), $product); // handleSelectedSizes

        $product ? flash('Product updated') : flash()->addError('Product could not be created');

        return back();
    }
}