<x-app-layout>
    <x-slot name="header">
        <h2 class="font-semibold text-xl text-gray-800 dark:text-gray-200 leading-tight">
            {{ __('Dashboard') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8 lg:w-2/3 ">
            <div class="p-10 bg-white dark:bg-gray-800 overflow-hidden shadow-sm sm:rounded-lg">
                <header class="mb-10">
                    Fill the form below to add a product to the online store
                </header>

                <form action="{{ route('products.store') }}" method="POST" enctype="multipart/form-data">@csrf
                    <div class="form-group my-5">
                        <x-input-label for="product_category" value="Product Category" class="my-2" />
                        <x-single-input-error field-name="categories" />
                        <select name="categories[]" class="w-full p-5" multiple>
                            @foreach ($allCategories as $category)
                                <option class="my-3 py-3" value="{{ $category->id }}" @selected(collect(old('categories'))->contains($category->id))>
                                    {{ $category->name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="form-group my-5">
                        <x-input-label for="product_name" value="Product Name" class="my-2" />
                        <x-text-input name="name" class="w-full" value="{{ old('name') }}" />
                        <x-single-input-error field-name="name" />

                    </div>

                    <div class="flex gap-5 w-full">
                        <div class="form-group w-full">
                            <x-input-label for="price" value="Product price" class="my-2" />
                            <x-text-input type='number' id="price" class="w-full" name="price"
                                value="{{ old('price') }}" />
                            <x-single-input-error field-name="price" />
                        </div>
                    </div>

                    <div class="form-group my-10">
                        <p class="my-5 text-xl">Available Sizes</p>
                        <label for='all_sizes' class="uppercase">All sizes
                            <input type="checkbox" name="all_sizes" id='all_sizes' @checked(old('all_sizes', 'all_sizes'))
                                value="all_sizes">
                        </label><br><br>

                        <div class="flex gap-5">
                            @foreach ($sizes as $size)
                                <x-udo.size-input-cmp :size="$size" :product="null" />
                            @endforeach
                        </div>
                    </div>

                    <div class="form-group my-10">
                        <x-input-label for="product_description" value="Description" />
                        <x-single-input-error field-name="description" />

                        <textarea rows="7" name="description" id="product_description"
                            class="border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm w-full">{{ old('description') }}</textarea>
                    </div>


                    <div class="form-group my-10">
                        <p class="my-5 text-xl">Attach related files</p>
                        <span>The first uploaded photo serves as the main image for the product</span>

                        {{-- futures --}}
                        {{-- <div class="multiple-file-upload-container">
                            <p class="text-xl font-semibold mt-10">Upload multiple files without captions eg. img1,
                                img2 etc.</p>
                            <div class=" bg-blue-600 my-5">
                                <input multiple type="file" name="bulk_images[]" id="image"
                                    class="p-5 w-full text-white  rounded-lg" accept=".png, .jpg, .jpeg" />
                            </div>
                        </div> --}}

                        @foreach (range(1, 6) as $item)
                            <input class="my-4" type="file" name="photo_{{ $item }}" id=""
                                accept=".jpg, .png, .jpeg">
                            <x-single-input-error field-name="photo_{{ $item }}" />
                        @endforeach
                    </div>

                    <x-primary-button>{{ __('Save product') }}</x-primary-button>

                </form>
            </div>
        </div>


    </div>
</x-app-layout>
