<x-app-layout>
    <x-slot name="header">
        <h2 class="font-semibold text-xl text-gray-800 dark:text-gray-200 leading-tight">
            {{ __('Modify Product') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8 lg:w-2/3 ">
            <div class="p-10 bg-white dark:bg-gray-800 overflow-hidden shadow-sm sm:rounded-lg">
                <header class="mb-10">
                    Fill the form below to edit this product
                </header>
                <x-input-error :messages="$errors->all()" />
                <form id="product_update_form" action="{{ route('products.update', $product->id) }}" method="POST"
                    enctype="multipart/form-data">@csrf
                    @method('PATCH')
                    <div class="form-group my-5">
                        <x-input-label for="product_category"
                            value="Product Category (please hold down the Ctrl Key when selecting multiple entries )"
                            class="my-2" />
                        <select name="categories[]" class="w-full p-5" multiple>
                            @foreach ($allCategories as $category)
                                <option @selected($product->categories->contains($category->id)) class="my-1 py-2" value="{{ $category->id }}">
                                    {{ $category->name }}
                                </option>
                            @endforeach
                        </select>
                    </div>

                    <div class="form-group my-5">
                        <x-input-label for="product_name" value="Product Name" class="my-2" />
                        <x-text-input name="name" class="w-full" value="{{ old('name', $product->name) }}" />
                    </div>

                    <div class="flex gap-5 w-full">
                        <div class="form-group w-full">
                            <x-input-label for="price" value="Product price" class="my-2" />
                            <x-text-input type='number' id="price" class="w-full" name="price"
                                value="{{ old('price', $product->price) }}" />
                        </div>

                        <div class="form-group w-full">
                            <x-input-label for="inventory" value="Product Qty (Inventory)" class="my-2" />
                            <x-text-input disabled type='number' id="inventory" class="w-full cursor-not-allowed"
                                name="inventory" value="{{ old('inventory', $product->inventory) }}" />
                        </div>

                    </div>

                    <div class="form-group my-10">
                        <p class="my-5">Available Sizes</p>
                        <label for='all_sizes' class="uppercase">All sizes
                            <input type="checkbox" @checked(productHasAllSizes($product)) name="sizes[]" id='all_sizes'
                                value="all_sizes">
                        </label><br><br>
                        <div class="flex gap-5">

                            @foreach ($sizes as $size)
                                <x-udo.size-input-cmp :size="$size" :product="$product" />
                            @endforeach

                        </div>


                    </div>

                    <div class="form-group my-10">
                        <x-input-label for="product_description" value="Description" />
                        <textarea rows="7" name="description" id="product_description"
                            class="border-gray-300 dark:border-gray-700 dark:bg-gray-900 dark:text-gray-300 focus:border-indigo-500 dark:focus:border-indigo-600 focus:ring-indigo-500 dark:focus:ring-indigo-600 rounded-md shadow-sm w-full">{{ old('description', $product->description) }}</textarea>
                    </div>

                    <div class="form-group my-10">
                        <p class="my-5 text-xl">Attach related files</p>
                        <span>The first uploaded photo serves as the main image for the product</span>

                        @foreach (range(1, 6) as $item)
                            <input class="my-4" type="file" name="photo_{{ $item }}" id=""
                                accept=".jpg, .png, .jpeg">
                            <x-single-input-error field-name="photo_{{ $item }}" />
                        @endforeach
                    </div>
                </form>

                @if (!blank($product->pictures))

                    <div class="form-group my-10">
                        <p class="my-5 text-xl">Remove related files</p>
                        <div class="flex gap-3">

                            @foreach ($product->pictures as $picture)
                                <div class="">
                                    <div class="w-[100px] h-[100px] picture_as_bg_img"
                                        style="background-image:url('{{ $picture->path }}');">
                                    </div>
                                    <form action="{{ route('product.pictures.destroy', $picture->id) }}" method="POST"
                                        class=" text-center">@method('DELETE') @csrf
                                        <button type="submit"
                                            class=" text-2xl cursor-pointer text-red-500 lni lni-trash-can"></button>
                                    </form>
                                    <x-single-input-error field-name="photo_{{ $item }}" />
                                </div>
                            @endforeach
                        </div>
                    </div>
                @endif


                {{-- submit button for the main form --}}
                <div class="mt-20">
                    <x-external-submit-button form="product_update_form">{{ __('Update Product') }}
                    </x-external-submit-button>
                </div>

                </form>
            </div>
        </div>


    </div>
</x-app-layout>
