<?php

use App\Http\Controllers\Tinkerz;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\CartController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\PaymentController;
use App\Http\Controllers\PictureController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\CheckoutController;
use App\Http\Controllers\PaystackController;
use App\Http\Controllers\WebPagesController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\BillingDataController;
use App\Http\Controllers\ReceiptGeneratorController;
use App\Http\Controllers\ProductCollectionController;

Route::get('/welcome', function () {
    return view('welcome');
});


// testing routes
Route::get('/flow', function () {
    return view('flow');
});
Route::view('carousel', 'carousel');

Route::get('tinker', Tinkerz::class);
// Actual routes
Route::get('/', [WebPagesController::class, 'landingpage'])->name('landingpage');

Route::resource('products', ProductController::class);
Route::get('search/products', [ProductCollectionController::class, 'search'])->name('products.search');
Route::resource('productCollections', ProductCollectionController::class)->middleware('auth');

Route::get('/cart', [WebPagesController::class, 'cart'])->name('cart');

Route::get('/wishlist', [WebPagesController::class, 'wishlist'])->name('wishlist');

Route::get('/move-to-cart/{product}', [CartController::class, 'moveToCart'])->name('move-to-cart');

Route::get('/cart-update/{product}', [CartController::class, 'updateCart'])->name('cart-update');

Route::get('/move-to-wishlist/{product}', [CartController::class, 'moveToWishlist'])->name('move-to-wishlist');

Route::get('/remove-from-wishlist/{product}', [CartController::class, 'removeFromWishlistWithRedirect'])->name('remove-from-wishlist');

Route::post('/add-to-cart/{product}', [CartController::class, 'addToCartWithRedirect'])->name('add-to-cart');

Route::post('/remove-from-cart/{product}', [CartController::class, 'removeFromCartWithRedirect'])->name('remove-from-cart');


Route::middleware('auth')->group(function () {
    Route::resource('orders', OrderController::class);
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    
    // modify productpictures
    Route::delete('/product/pictures/{picture}', [PictureController::class, 'destroy'])->name('product.pictures.destroy');
    
    


    Route::post('dp/update', [ProfileController::class, 'updateDp'])->name('displayphoto.update');
    
    Route::get('admin/products', [ProductController::class, 'adminIndex'])->name('admin.products.index');

    Route::get('/checkout', [WebPagesController::class, 'checkout'])->name('checkout');

    Route::post('checkout', CheckoutController::class)->name('checkout.process');

    Route::post('billing-info', [BillingDataController::class, 'storeOrUpdate'])->name('update-billing-info');

    Route::get('/dashboard', DashboardController::class)->middleware(['auth', 'verified'])->name('dashboard');


    // payment routes
    Route::get('process-payment/{order}', [PaymentController::class, 'handlePayment'])->name('process-payment');

    /*
    |--------------------------------------------------------------------------
    | Paystack testing Routes
    |--------------------------------------------------------------------------
    */
    Route::get('/paystack/initiate', [PaystackController::class, 'initiateTest'])
        ->name('paystack.initiate.test');

    Route::get('/paystack/verify', [PaystackController::class, 'verifyTest'])
        ->name('paystack.verify.test');

    /*
    |--------------------------------------------------------------------------
    | Paystack operational Routes
    |--------------------------------------------------------------------------
    */

    // callback route for transactions (successful or failed)
    Route::get('/paystack/callback', [PaystackController::class, 'callback'])
        ->name('paystack.callback');

    // when a user cancels the transaction from paystack payment ui
    Route::get('/paystack/cancel_action', [PaystackController::class, 'canceledByUser'])
        ->name('paystack.cancel_action');

    Route::get('/payment-receipt/{relatedOrder}', ReceiptGeneratorController::class)
        ->name('payment-receipt.show');
});

require __DIR__ . '/auth.php';
